

#' @title Chapter 3: Some Basic Probability Concepts
#' 
#' @description 
#' 
#' Examples in Chapter 3, \emph{Some Basic Probability Concepts}.
#' 
#' @return 
#' No function defined for Chapter 3.
#' 
# @seealso \link[stats]{addmargins} \link[base]{rowSums} \link[base]{colSums} \link[base]{proportions} 
#' 
#' @example inst/extexample/Chapter3.R 
#' 
#' @name Chapter03
NULL


